@@ -36,12 +36,12 @@ class ImageNode(AssetNode):
                 size[1] = int(size[1])
                 image.thumbnail(size, Image.ANTIALIAS)
                 image.save(target_path)
-            elif self['verbose']:
+            elif self['__verbose']:
                 sys.stderr.write("Skipping %s\n" % target_path)
         else:
             if not self['skip']:
                 copy2(source_path, target_path)
-            elif self['verbose']:
+            elif self['__verbose']:
                 sys.stderr.write("Skipping %s\n" % target_path)
         self.files_tracked.append(source_path)
         self.files_written.append(target_path)
